pub struct IsAuthenticatedOrReadOnly;Expand description
IsAuthenticatedOrReadOnly - authenticated for writes, allow reads
This permission allows read-only access (GET, HEAD, OPTIONS) to all users, but requires authentication for write operations (POST, PUT, PATCH, DELETE).
Examples
use reinhardt_auth::{Permission, IsAuthenticatedOrReadOnly, PermissionContext};
use reinhardt_http::Request;
use hyper::{Method, Uri, Version, header::HeaderMap};
use bytes::Bytes;
let permission = IsAuthenticatedOrReadOnly;
// GET request from anonymous user - allowed
let mut request = Request::builder()
.method(Method::GET)
.uri("/")
.version(Version::HTTP_11)
.headers(HeaderMap::new())
.body(Bytes::new())
.build()
.unwrap();
request.method = Method::GET;
let context = PermissionContext {
request: &request,
is_authenticated: false,
is_admin: false,
is_active: false,
user: None,
};
assert!(permission.has_permission(&context).await);
// POST request from anonymous user - denied
request.method = Method::POST;
let context = PermissionContext {
request: &request,
is_authenticated: false,
is_admin: false,
is_active: false,
user: None,
};
assert!(!permission.has_permission(&context).await);
// POST request from authenticated user - allowed
let context = PermissionContext {
request: &request,
is_authenticated: true,
is_admin: false,
is_active: true,
user: None,
};
assert!(permission.has_permission(&context).await);Trait Implementations
Sourceimpl<B> BitAnd<B> for IsAuthenticatedOrReadOnlywhere
B: Permission,
impl<B> BitAnd<B> for IsAuthenticatedOrReadOnlywhere
B: Permission,
Sourcetype Output = AndPermission<IsAuthenticatedOrReadOnly, B>
type Output = AndPermission<IsAuthenticatedOrReadOnly, B>
The resulting type after applying the
& operator.Sourceimpl<B> BitOr<B> for IsAuthenticatedOrReadOnlywhere
B: Permission,
impl<B> BitOr<B> for IsAuthenticatedOrReadOnlywhere
B: Permission,
Sourcetype Output = OrPermission<IsAuthenticatedOrReadOnly, B>
type Output = OrPermission<IsAuthenticatedOrReadOnly, B>
The resulting type after applying the
| operator.Sourceimpl Clone for IsAuthenticatedOrReadOnly
impl Clone for IsAuthenticatedOrReadOnly
Sourcefn clone(&self) -> IsAuthenticatedOrReadOnly
fn clone(&self) -> IsAuthenticatedOrReadOnly
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for IsAuthenticatedOrReadOnly
impl Default for IsAuthenticatedOrReadOnly
Sourcefn default() -> IsAuthenticatedOrReadOnly
fn default() -> IsAuthenticatedOrReadOnly
Returns the “default value” for a type. Read more
Sourceimpl Not for IsAuthenticatedOrReadOnly
impl Not for IsAuthenticatedOrReadOnly
Sourcetype Output = NotPermission<IsAuthenticatedOrReadOnly>
type Output = NotPermission<IsAuthenticatedOrReadOnly>
The resulting type after applying the
! operator.Sourceimpl Permission for IsAuthenticatedOrReadOnly
impl Permission for IsAuthenticatedOrReadOnly
Sourcefn has_permission<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
context: &'life1 PermissionContext<'life2>,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
IsAuthenticatedOrReadOnly: 'async_trait,
fn has_permission<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
context: &'life1 PermissionContext<'life2>,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
IsAuthenticatedOrReadOnly: 'async_trait,
Checks if the user has permission to perform the action Read more
impl Copy for IsAuthenticatedOrReadOnly