MultiPartParser

Struct MultiPartParser 

pub struct MultiPartParser {
    pub max_file_size: Option<usize>,
    pub max_total_size: Option<usize>,
}
MultiPart parser for multipart/form-data content type (file uploads)

By default, enforces sensible size limits to prevent denial-of-service via large uploads:

  • Per-file limit: 10 MB
  • Total upload limit: 50 MB

Use the builder methods to override these limits, or MultiPartParser::unlimited() to remove all limits.

Fields

max_file_size: Option<usize>

Maximum file size in bytes (None = unlimited)

max_total_size: Option<usize>

Maximum total size in bytes (None = unlimited)

Implementations

Source

impl MultiPartParser

pub fn new() -> MultiPartParser

Create a new MultiPartParser with default size limits.

Default limits:

  • Per-file: 10 MB
  • Total: 50 MB
Examples
use reinhardt_core::parsers::multipart::MultiPartParser;

let parser = MultiPartParser::new();
assert_eq!(parser.max_file_size, Some(10 * 1024 * 1024));
assert_eq!(parser.max_total_size, Some(50 * 1024 * 1024));
pub fn unlimited() -> MultiPartParser

Create a new MultiPartParser with no size limits.

Safety Note

Using unlimited uploads without external size controls (e.g., reverse proxy limits) may expose the server to denial-of-service attacks.

Examples
use reinhardt_core::parsers::multipart::MultiPartParser;

let parser = MultiPartParser::unlimited();
assert!(parser.max_file_size.is_none());
assert!(parser.max_total_size.is_none());
pub fn max_file_size(self, size: usize) -> MultiPartParser

Set the maximum file size in bytes for individual files.

Examples
use reinhardt_core::parsers::multipart::MultiPartParser;

let parser = MultiPartParser::new().max_file_size(1024 * 1024); // 1MB
assert_eq!(parser.max_file_size, Some(1024 * 1024));
pub fn max_total_size(self, size: usize) -> MultiPartParser

Set the maximum total size in bytes for all uploaded files combined.

Examples
use reinhardt_core::parsers::multipart::MultiPartParser;

let parser = MultiPartParser::new().max_total_size(10 * 1024 * 1024); // 10MB
assert_eq!(parser.max_total_size, Some(10 * 1024 * 1024));