pub struct SimpleUser {
pub id: Uuid,
pub username: String,
pub email: String,
pub is_active: bool,
pub is_admin: bool,
pub is_staff: bool,
pub is_superuser: bool,
}Expand description
Simple user implementation with basic fields
This is a lightweight user struct suitable for most applications.
Examples
use reinhardt_auth::{User, SimpleUser};
use uuid::Uuid;
let user = SimpleUser {
id: Uuid::new_v4(),
username: "bob".to_string(),
email: "bob@example.com".to_string(),
is_active: true,
is_admin: true,
is_staff: true,
is_superuser: false,
};
assert!(user.is_authenticated());
assert!(user.is_admin());
assert!(user.is_staff());Fields
id: Uuidusername: Stringemail: Stringis_active: boolis_admin: boolis_staff: boolis_superuser: boolTrait Implementations
Sourceimpl Clone for SimpleUser
impl Clone for SimpleUser
Sourcefn clone(&self) -> SimpleUser
fn clone(&self) -> SimpleUser
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleUser
impl Debug for SimpleUser
Sourceimpl<'de> Deserialize<'de> for SimpleUser
impl<'de> Deserialize<'de> for SimpleUser
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SimpleUser, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SimpleUser, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for SimpleUser
impl Serialize for SimpleUser
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl User for SimpleUser
impl User for SimpleUser
Sourcefn is_authenticated(&self) -> bool
fn is_authenticated(&self) -> bool
Returns whether this user is authenticated Read more
Sourcefn is_superuser(&self) -> bool
fn is_superuser(&self) -> bool
Returns whether this user is a superuser Read more
Sourcefn get_username(&self) -> &str
fn get_username(&self) -> &str
Returns the username (alias for
username()) Read moreAuto Trait Implementations
impl Freeze for SimpleUser
impl RefUnwindSafe for SimpleUser
impl Send for SimpleUser
impl Sync for SimpleUser
impl Unpin for SimpleUser
impl UnsafeUnpin for SimpleUser
impl UnwindSafe for SimpleUser